@@ -23,8 +23,6 @@
 #include <vector>
 #include <stdint.h>
 
-#include <AL/al.h>
-#include <AL/alc.h>
 #include <AL/alut.h>
 
 #include "audio_output.h"
